@@ -35,6 +35,9 @@
 #include "platforms/linux/mauilinux.h"
 #endif
 
+#include "shadowhelper/windowshadow.h"
+#include "blurhelper/windowblur.h"
+
 #include "platform.h"
 
 #include <KI18n/KLocalizedContext>
@@ -58,9 +61,7 @@ void MauiKit::initializeEngine(QQmlEngine *engine, const char *uri)
 }
 
 void MauiKit::registerTypes(const char *uri)
-{
-//     Q_ASSERT(uri == QLatin1String(MAUIKIT_URI));
-
+{   
     qmlRegisterSingletonType(componentUrl(QStringLiteral("Style.qml")), uri, 1, 0, "Style");
     qmlRegisterType(componentUrl(QStringLiteral("ToolBar.qml")), uri, 1, 0, "ToolBar");
     qmlRegisterType(componentUrl(QStringLiteral("ApplicationWindow.qml")), uri, 1, 0, "ApplicationWindow");
@@ -153,7 +154,7 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterUncreatableType<TabViewInfo>(uri, 1, 3, "TabViewInfo", "Cannot be created TabView");
 
     qmlRegisterType<SettingSection>(uri, 1, 2, "SettingSection");
-//     qmlRegisterSingletonInstance<Platform>(uri, 1, 2, "Platform", Platform::instance());
+    //     qmlRegisterSingletonInstance<Platform>(uri, 1, 2, "Platform", Platform::instance());
     qmlRegisterSingletonType<Platform>(uri, 1, 2, "Platform", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
         Q_UNUSED(scriptEngine)
         auto platform = Platform::instance();
@@ -170,7 +171,7 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsWindows.qml")), uri, 1, 1, "WindowControls");
 #elif defined Q_OS_LINUX && !defined Q_OS_ANDROID
 
-    #if defined Q_PROCESSOR_ARM
+#if defined Q_PROCESSOR_ARM
     qmlRegisterType(componentUrl(QStringLiteral("labs/WindowControlsWindows.qml")), uri, 1, 1, "WindowControls");
 #else
     qmlRegisterType(componentUrl(QStringLiteral("labs/CSDControls.qml")), uri, 1, 1, "CSDControls");
@@ -192,13 +193,15 @@ void MauiKit::registerTypes(const char *uri)
     });
 #elif defined Q_OS_LINUX
     qmlRegisterUncreatableType<MAUIKDE>(uri, 1, 0, "KDE", "Cannot be created KDE");
-
 #elif defined Q_OS_WIN32
     // here window platform integration interfaces
 #elif defined Q_OS_MACOS
 
 #endif
 
+    qmlRegisterType<WindowShadow>(uri, 1, 0, "WindowShadow");
+    qmlRegisterType<WindowBlur>(uri, 1, 0, "WindowBlur");
+    
     /** DATA MODELING TEMPLATED INTERFACES **/
     qmlRegisterAnonymousType<MauiList>(uri, 1); // ABSTRACT BASE LIST
     qmlRegisterType<MauiModel>(uri, 1, 0, "BaseModel"); // BASE MODEL
