@@ -18,27 +18,14 @@
 
 #include "mauimodel.h"
 #include "mauilist.h"
-
+#include <QDebug>
 #include <QDateTime>
 
 MauiModel::MauiModel(QObject *parent)
     : QSortFilterProxyModel(parent)
     , m_model(new PrivateAbstractListModel(this))
 {
-    this->setSourceModel(this->m_model);
-    this->setDynamicSortFilter(true);
-}
-
-void MauiModel::setFilterString(const QString &string)
-{
-    this->setFilterCaseSensitivity(Qt::CaseInsensitive);
-    this->setFilterFixedString(string);
-    //     this->setFilterRegExp(QRegExp(string, Qt::CaseInsensitive));
-}
-
-void MauiModel::setSortOrder(const int &sortOrder)
-{
-    this->sort(0, static_cast<Qt::SortOrder>(sortOrder));
+   
 }
 
 QVariantMap MauiModel::get(const int &index) const
@@ -78,6 +65,11 @@ const QString MauiModel::getFilter() const
     return this->m_filter;
 }
 
+QString MauiModel::getFilterRoleName() const
+{
+    return m_filter;
+}
+
 void MauiModel::setSortOrder(const Qt::SortOrder &sortOrder)
 {
     if (this->m_sortOrder == sortOrder)
@@ -109,6 +101,11 @@ QString MauiModel::getSort() const
     return this->m_sort;
 }
 
+int MauiModel::count() const
+{
+    return this->rowCount();
+}
+
 int MauiModel::mappedFromSource(const int &index) const
 {
     return this->mapFromSource(this->m_model->index(index, 0)).row();
@@ -119,6 +116,16 @@ int MauiModel::mappedToSource(const int &index) const
     return this->mapToSource(this->index(index, 0)).row();
 }
 
+void MauiModel::setFilterRoleName(QString filter)
+{
+    if (m_filterRoleName == filter)
+        return;
+
+    m_filterRoleName = filter;
+    emit filterRoleNameChanged(m_filterRoleName);
+    this->setFilterRole(FMH::MODEL_NAME_KEY[m_filterRoleName]);
+}
+
 bool MauiModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
     if (this->filterRole() != Qt::DisplayRole) {
@@ -142,103 +149,96 @@ bool MauiModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent)
 
 MauiList *MauiModel::getList() const
 {
-    return this->m_model->getList();
+    return this->m_list;
 }
 
-MauiList *MauiModel::PrivateAbstractListModel::getList() const
-{
-    return this->list;
-}
-
-void MauiModel::PrivateAbstractListModel::setList(MauiList *value)
+void MauiModel::PrivateAbstractListModel::setUpList()
 {
     beginResetModel();
 
-    if (this->list)
-        this->list->disconnect(this);
+    if (m_model->getList())
+        m_model->getList()->disconnect(this);
 
-    this->list = value;
-
-    if (this->list) {
+    if (m_model->getList()) {
         connect(
-            this->list,
+            m_model->getList(),
             &MauiList::preItemAppendedAt,
             this,
-            [=](int index) {
+            [this](int index) {
                 beginInsertRows(QModelIndex(), index, index);
             },
             Qt::DirectConnection);
 
         connect(
-            this->list,
+            m_model->getList(),
             &MauiList::preItemAppended,
             this,
-            [=]() {
-                const int index = this->list->items().size();
+            [this]() {
+                const int index = m_model->getList()->getCount();
                 beginInsertRows(QModelIndex(), index, index);
             },
             Qt::DirectConnection);
 
         connect(
-            this->list,
+            m_model->getList(),
             &MauiList::preItemsAppended,
             this,
-            [=](uint count) {
-                const int index = this->list->items().size();
+            [this](uint count) {
+                const int index = m_model->getList()->getCount();
                 beginInsertRows(QModelIndex(), index, index + count - 1);
             },
             Qt::DirectConnection);
 
         connect(
-            this->list,
+            m_model->getList(),
             &MauiList::postItemAppended,
             this,
-            [=]() {
+            [this]() {
                 endInsertRows();
             },
             Qt::DirectConnection);
 
         connect(
-            this->list,
+            m_model->getList(),
             &MauiList::preItemRemoved,
             this,
-            [=](int index) {
+            [this](int index) {
                 beginRemoveRows(QModelIndex(), index, index);
             },
             Qt::DirectConnection);
 
         connect(
-            this->list,
+            m_model->getList(),
             &MauiList::postItemRemoved,
             this,
-            [=]() {
+            [this]() {
                 endRemoveRows();
             },
             Qt::DirectConnection);
 
         connect(
-            this->list,
+            m_model->getList(),
             &MauiList::updateModel,
             this,
-            [=](int index, QVector<int> roles) {
-                emit this->dataChanged(this->index(index), this->index(index), roles);
+            [this](int index, QVector<int> roles) {
+                emit this->dataChanged(this->m_model->index(index, 0), this->m_model->index(index, 0), roles);
             },
             Qt::DirectConnection);
 
         connect(
-            this->list,
+            m_model->getList(),
             &MauiList::preListChanged,
             this,
-            [=]() {
+            [this]() {
                 beginResetModel();
             },
             Qt::DirectConnection);
 
         connect(
-            this->list,
+            m_model->getList(),
             &MauiList::postListChanged,
             this,
-            [=]() {
+            [this]() {
                 endResetModel();
             },
             Qt::DirectConnection);
@@ -249,15 +249,20 @@ void MauiModel::PrivateAbstractListModel::setList(MauiList *value)
 
 void MauiModel::setList(MauiList *value)
 {
-    value->modelHooked();
-    this->m_model->setList(value);
-    this->getList()->m_model = this;
-    emit this->listChanged();
+    if(value && value != this->m_list)
+    {
+        value->modelHooked();
+        this->m_list = value;
+        this->m_model->setUpList();
+        emit this->listChanged();
+        
+        this->setSourceModel(this->m_model);
+        this->setDynamicSortFilter(true);
+    }
 }
 
 MauiModel::PrivateAbstractListModel::PrivateAbstractListModel(MauiModel *model)
     : QAbstractListModel(model)
-    , list(nullptr)
     , m_model(model)
 {
     connect(
@@ -265,8 +270,8 @@ MauiModel::PrivateAbstractListModel::PrivateAbstractListModel(MauiModel *model)
         &QAbstractListModel::rowsInserted,
         this,
         [this](QModelIndex, int, int) {
-            if (this->list) {
-                emit this->list->countChanged();
+            if (m_model->getList()) {
+                emit this->m_model->countChanged();
             }
         },
         Qt::DirectConnection);
@@ -276,8 +281,8 @@ MauiModel::PrivateAbstractListModel::PrivateAbstractListModel(MauiModel *model)
         &QAbstractListModel::rowsRemoved,
         this,
         [this](QModelIndex, int, int) {
-            if (this->list) {
-                emit this->list->countChanged();
+            if (m_model->getList()) {
+                emit this->m_model->countChanged();
             }
         },
         Qt::DirectConnection);
@@ -285,18 +290,21 @@ MauiModel::PrivateAbstractListModel::PrivateAbstractListModel(MauiModel *model)
 
 int MauiModel::PrivateAbstractListModel::rowCount(const QModelIndex &parent) const
 {
-    if (parent.isValid() || !list)
+    if (parent.isValid() || !m_model->getList())
+    {        
         return 0;
-
-    return list->items().size();
+    }    
+        
+    return m_model->getList()->getCount();
 }
+    
 
 QVariant MauiModel::PrivateAbstractListModel::data(const QModelIndex &index, int role) const
 {
-    if (!index.isValid() || !list)
+    if (!index.isValid() || !m_model->getList())
         return QVariant();
 
-    auto value = list->items().at(index.row())[static_cast<FMH::MODEL_KEY>(role)];
+    auto value = m_model->getList()->getItem(index.row()).value(static_cast<FMH::MODEL_KEY>(role));
 
     if (role == FMH::MODEL_KEY::ADDDATE || role == FMH::MODEL_KEY::DATE || role == FMH::MODEL_KEY::MODIFIED || role == FMH::MODEL_KEY::RELEASEDATE) {
         const auto date = QDateTime::fromString(value, Qt::TextDate);
@@ -327,9 +335,12 @@ Qt::ItemFlags MauiModel::PrivateAbstractListModel::flags(const QModelIndex &inde
 QHash<int, QByteArray> MauiModel::PrivateAbstractListModel::roleNames() const
 {
     QHash<int, QByteArray> names;
+    const auto keys = FMH::MODEL_NAME.keys();
 
-    for (const auto &key : FMH::MODEL_NAME.keys())
+    for (const auto &key : keys)
+    {
         names[key] = QString(FMH::MODEL_NAME[key]).toUtf8();
+    }
 
     return names;
 }
